@@ -1,7 +1,6 @@
 #! /usr/bin/env python3
 
-"""This is the "pydwf" support tool that can be executed as "python -m pydwf".
-"""
+"""This is the pydwf support tool that can be executed as 'python -m pydwf'."""
 
 import zipfile
 import io
@@ -17,7 +16,7 @@ from pydwf import DwfLibrary, DwfEnumConfigInfo
 
 
 def show_version():
-    """Show pydwf and DWF library version number."""
+    """Show the pydwf and DWF library version number."""
 
     dwf = DwfLibrary()
     print("pydwf version ............ : {}".format(pydwf.__version__))
@@ -25,7 +24,7 @@ def show_version():
 
 
 def list_devices(use_obsolete_api: bool, list_configurations: bool, full_tooltips_flag: bool):
-    """List devices supported by the DWF library."""
+    """List the devices supported by the DWF library."""
 
     # pylint: disable = too-many-locals, too-many-branches, too-many-statements, too-many-nested-blocks
 
@@ -54,12 +53,12 @@ def list_devices(use_obsolete_api: bool, list_configurations: bool, full_tooltip
         print(header)
         print("=" * len(header))
         print()
-        print("  device .......... : {}".format(device_type[0]))
-        print("  version ......... : {}".format(device_type[1]))
-        print("  open ............ : {}".format(is_open))
-        print("  user_name ....... : {!r}".format(user_name))
+        print("  device ........... : {}".format(device_type[0]))
+        print("  version .......... : {}".format(device_type[1]))
+        print("  open ............. : {}".format(is_open))
+        print("  user_name ........ : {!r}".format(user_name))
         print("  device_name ...... : {!r}".format(device_name))
-        print("  serial .......... : {!r}".format(serial))
+        print("  serial ........... : {!r}".format(serial))
         print()
 
         if use_obsolete_api:
@@ -128,7 +127,7 @@ def list_devices(use_obsolete_api: bool, list_configurations: bool, full_tooltip
 
                 max_width = 80
 
-                print("  strings referenced in the preceding table (with newlines replaced by '•'):")
+                print("  Strings referenced in the preceding table (with newlines replaced by '•'):")
                 print()
                 for (k, v) in string_lookup_table.items():
                     k = k.replace('\n', '•')
@@ -141,7 +140,7 @@ def list_devices(use_obsolete_api: bool, list_configurations: bool, full_tooltip
                         idx += max_width
                         if idx >= len(k):
                             break
-                print()
+                    print()
 
 
 def extract_zipfile(import_name, target):
