@@ -62,13 +62,13 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def status(self, read_data: bool) -> DwfState:
-        """Get |AnalogIn| instrument state.
+    def status(self, read_data_flag: bool) -> DwfState:
+        """Get the |AnalogIn| instrument state.
 
         Executing this method initiates a status request to the |AnalogIn| instrument and receives its response.
 
         The following methods can be used to retrieve |AnalogIn| instrument status information
-        as a result of this call, regardless of the value of *read_data*:
+        as a result of this call, regardless of the value of the *read_data_flag* parameter:
 
         * :py:meth:`~statusTime`
         * :py:meth:`~statusSample`
@@ -78,8 +78,8 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         * :py:meth:`~statusIndexWrite`
         * :py:meth:`~statusRecord`
 
-        The following methods can be used to retrieve bulk data obtained from the *AnalogIn* instrument
-        as a result of this call, but only if *read_data* is True:
+        The following methods can be used to retrieve bulk data obtained from the |AnalogIn| instrument
+        as a result of this call, but only if the *read_data_flag* parameter is True:
 
         * :py:meth:`~statusData`
         * :py:meth:`~statusData2`
@@ -88,9 +88,9 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         * :py:meth:`~statusNoise2`
 
         Parameters:
-            read_data (bool): If True, read sample data from the instrument.
+            read_data_flag (bool): If True, read sample data from the instrument.
 
-                For :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Single` acquisition mode,
+                In :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Single` acquisition mode,
                 the data will be read only when the acquisition is finished.
 
         Returns:
@@ -100,7 +100,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             DwfLibraryError: An error occurred while executing the *status* operation.
         """
         c_status = typespec_ctypes.DwfState()
-        result = self.lib.FDwfAnalogInStatus(self.hdwf, read_data, c_status)
+        result = self.lib.FDwfAnalogInStatus(self.hdwf, read_data_flag, c_status)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
         status_ = DwfState(c_status.value)
@@ -446,7 +446,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         This number of bits can only be queried; it cannot be changed.
 
         Note:
-            The Analog Discovery 2 uses an |Analog Devices AD964| two-channel ADC. It converts 14-bit samples at a rate
+            The Analog Discovery 2 uses an |Analog Devices AD9648| two-channel ADC. It converts 14-bit samples at a rate
             of up to 125 MHz. So for the Analog Discovery 2, this method always returns 14.
 
         Returns:
