@@ -396,7 +396,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get a list of valid |AnalogOut| instrument trigger sources.
 
         Warning:
-            This method is obsolete. Use the generic |DwfDevice.triggerInfo:link| method instead.
+            **This method is obsolete.**
+
+            Use the generic |DwfDevice.triggerInfo:link| method instead.
 
         Returns:
             List[DwfTriggerSource]: The list of DwfTriggerSource values that can be configured.
@@ -1266,7 +1268,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Enable or disable the specified |AnalogOut| channel.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeEnableSet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeEnableSet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1283,7 +1287,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the current enable/disable status of the specified |AnalogOut| channel.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeEnableGet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeEnableGet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1305,7 +1311,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel waveform shape function info.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeFunctionInfo` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeFunctionInfo` method instead.
 
         Returns:
             List[DwfAnalogOutFunction]: The valid waveform shape functions.
@@ -1329,7 +1337,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Set the |AnalogOut| channel waveform shape function.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeFunctionSet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeFunctionSet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1346,7 +1356,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel waveform shape function.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeFunctionGet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeFunctionGet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1368,7 +1380,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel valid frequency range, in Hz.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeFrequencyInfo` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeFrequencyInfo` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1392,7 +1406,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Set the |AnalogOut| channel frequency, in Hz.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeFrequencySet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeFrequencySet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1409,7 +1425,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel frequency, in Hz.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeFrequencyGet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeFrequencyGet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1431,7 +1449,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel amplitude range info.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeAmplitudeInfo` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeAmplitudeInfo` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1455,7 +1475,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Set the |AnalogOut| channel amplitude.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeAmplitudeSet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeAmplitudeSet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1472,7 +1494,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel amplitude.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeAmplitudeGet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeAmplitudeGet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1494,7 +1518,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel offset range info, in Volts.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeOffsetInfo` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeOffsetInfo` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1518,7 +1544,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Set the |AnalogOut| channel offset, in Volts.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeOffsetSet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeOffsetSet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1535,7 +1563,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel offset, in Volts.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeOffsetGet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeOffsetGet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1557,7 +1587,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel symmetry setting range.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeSymmetryInfo` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeSymmetryInfo` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1581,7 +1613,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Set the |AnalogOut| channel symmetry setting.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeSymmetrySet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeSymmetrySet` method instead.
 
         Parameters:
             channel_index (int):  The |AnalogOut| channel.
@@ -1598,7 +1632,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel symmetry setting.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeSymmetryGet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeSymmetryGet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1620,7 +1656,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel phase range, in degrees.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodePhaseInfo` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodePhaseInfo` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1644,7 +1682,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Set the |AnalogOut| channel phase, in degrees.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodePhaseSet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodePhaseSet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1661,7 +1701,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel phase, in degrees.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodePhaseGet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodePhaseGet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1689,7 +1731,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel data buffer info.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeDataInfo` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeDataInfo` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1713,7 +1757,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Set the |AnalogOut| channel data.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodeDataSet` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodeDataSet` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1737,7 +1783,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Get the |AnalogOut| channel playback status, in samples.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodePlayStatus` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodePlayStatus` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1768,7 +1816,9 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         """Provide the |AnalogOut| channel playback data.
 
         Warning:
-            This method is obsolete. Use the :py:meth:`nodePlayData` method instead.
+            **This method is obsolete.**
+
+            Use the :py:meth:`nodePlayData` method instead.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
