@@ -21,12 +21,13 @@ class DeviceControl(AbstractDwfLibrarySubApi):
     """
 
     def open(self, device_index: int, config_index: Optional[int] = None) -> DwfDevice:
-        """Open a Digilent Waveforms device identified by the device index and (optionally)
-        the device configuration index.
+        """Open a Digilent Waveforms device identified by the device index, using a specific
+        device configuration index if specified.
 
         Note:
-            This method combines the functionality of the C API functions *FDwfDeviceOpen* and *FDwfDeviceConfigOpen*
-            into a single method. The call that is actually made depends on the value of the *config_index* parameter.
+            This method combines the functionality of the C API functions 'FDwfDeviceOpen()' and
+            'FDwfDeviceConfigOpen()' into a single method.
+            The call that is actually made depends on the value of the *config_index* parameter.
 
         Note:
             This method can take several seconds to complete.
