@@ -60,7 +60,26 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def status(self, read_data_flag: bool) -> DwfState:
-        """Get |DigitalIn| instrument state.
+        """Get the |DigitalIn| instrument state.
+
+        Executing this method initiates a status request to the |DigitalIn| instrument and receives its response.
+
+        The following methods can be used to retrieve |DigitalIn| instrument status information
+        as a result of this call, regardless of the value of the *read_data_flag* parameter:
+
+        * :py:meth:`~statusTime`
+        * :py:meth:`~statusAutoTriggered`
+        * :py:meth:`~statusSamplesLeft`
+        * :py:meth:`~statusSamplesValid`
+        * :py:meth:`~statusIndexWrite`
+        * :py:meth:`~statusRecord`
+
+        The following methods can be used to retrieve bulk data obtained from the |DigitalIn| instrument
+        as a result of this call, but only if the *read_data_flag* parameter is True:
+
+        * :py:meth:`~statusData`
+        * :py:meth:`~statusData2`
+        * :py:meth:`~statusNoise2`
 
         Parameters:
             read_data_flag (bool): Whether to read data.
@@ -217,7 +236,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         It copies the data samples to the provided buffer.
 
         Todo:
-            Figure out data format.
+            Figure out the data format.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -235,7 +254,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         """Retrieve the acquired data samples from the |DigitalIn| instrument.
 
         Todo:
-            Figure out data format.
+            Figure out the data format.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -254,7 +273,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         """Get the noise data from the |DigitalIn| instrument.
 
         Todo:
-            Figure out data format.
+            Figure out the data format.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -611,6 +630,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     def sampleSensibleGet(self) -> int:
         """Get the |DigitalIn| instrument *sample sensible* setting.
 
+        This setting is only used in :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Record` mode.
+
+        It select the signals to be used for data compression in record acquisition mode.
+
         Todo:
             Figure out what this setting does.
 
@@ -632,6 +655,13 @@ class DigitalIn(AbstractDwfDeviceSubApi):
 
         This setting is only used in :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Record` mode.
 
+        It determines the number of samples to acquire before arming in
+        :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Record` acquisition mode. The prefill is used for
+        recording with a trigger to make sure that at least the required number of samples are collected before arming.
+
+        Todo:
+            Figure out what this setting does, precisely.
+
         Parameters:
             samples_before_trigger (int): The prefill count, in samples.
 
@@ -716,6 +746,35 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         trigger_source = DwfTriggerSource(c_trigger_source.value)
         return trigger_source
 
+    def triggerSlopeSet(self, trigger_slope: DwfTriggerSlope) -> None:
+        """Set |DigitalIn| trigger detector slope.
+
+        Parameters:
+            trigger_slope (DwfTriggerSlope): The trigger slope to be configured.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfDigitalInTriggerSlopeSet(self.hdwf, trigger_slope.value)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def triggerSlopeGet(self) -> DwfTriggerSlope:
+        """Get |DigitalIn| trigger detector slope.
+
+        Returns:
+            DwfTriggerSlope: The currently configured trigger slope.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_trigger_slope = typespec_ctypes.DwfTriggerSlope()
+        result = self.lib.FDwfDigitalInTriggerSlopeGet(self.hdwf, c_trigger_slope)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        trigger_slope = DwfTriggerSlope(c_trigger_slope.value)
+        return trigger_slope
+
     def triggerPositionInfo(self) -> int:
         """Get |DigitalIn| trigger position info.
 
@@ -826,70 +885,52 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     #                                                                                                                  #
     ####################################################################################################################
 
-    def triggerSlopeSet(self, trigger_slope: DwfTriggerSlope) -> None:
-        """Set |DigitalIn| trigger detector slope.
-
-        Parameters:
-            trigger_slope (DwfTriggerSlope): The trigger slope to be configured.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        result = self.lib.FDwfDigitalInTriggerSlopeSet(self.hdwf, trigger_slope.value)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def triggerSlopeGet(self) -> DwfTriggerSlope:
-        """Get |DigitalIn| trigger detector slope.
-
-        Returns:
-            DwfTriggerSlope: The currently configured trigger slope.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        c_trigger_slope = typespec_ctypes.DwfTriggerSlope()
-        result = self.lib.FDwfDigitalInTriggerSlopeGet(self.hdwf, c_trigger_slope)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        trigger_slope = DwfTriggerSlope(c_trigger_slope.value)
-        return trigger_slope
-
     def triggerInfo(self) -> Tuple[int, int, int, int]:
         """Get |DigitalIn| detector trigger info.
 
+        Return the pins that support the different types of triggering. Each integer is a bitmask, representing pins\
+            that can be used as *low level*, *high level*, *rising edge*, and *falling edge* triggers.
+
         Returns:
-            Tuple[int, int, int, int]: (to be documented)
+            Tuple[int, int, int, int]: Digital pins that can be used as *low level*, *high level*, *rising edge*,
+            and *falling edge* triggers, respectively.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_fsLevelLow  = typespec_ctypes.c_unsigned_int()
-        c_fsLevelHigh = typespec_ctypes.c_unsigned_int()
-        c_fsEdgeRise  = typespec_ctypes.c_unsigned_int()
-        c_fsEdgeFall  = typespec_ctypes.c_unsigned_int()
+        c_level_low = typespec_ctypes.c_unsigned_int()
+        c_level_high = typespec_ctypes.c_unsigned_int()
+        c_edge_rise = typespec_ctypes.c_unsigned_int()
+        c_edge_fall = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalInTriggerInfo(
             self.hdwf,
-            c_fsLevelLow,
-            c_fsLevelHigh,
-            c_fsEdgeRise,
-            c_fsEdgeFall)
+            c_level_low,
+            c_level_high,
+            c_edge_rise,
+            c_edge_fall)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        fsLevelLow  = c_fsLevelLow.value
-        fsLevelHigh = c_fsLevelHigh.value
-        fsEdgeRise  = c_fsEdgeRise.value
-        fsEdgeFall  = c_fsEdgeFall.value
-        return (fsLevelLow, fsLevelHigh, fsEdgeRise, fsEdgeFall)
+        level_low = c_level_low.value
+        level_high = c_level_high.value
+        edge_rise = c_edge_rise.value
+        edge_fall = c_edge_fall.value
+        return (level_low, level_high, edge_rise, edge_fall)
 
     def triggerSet(self, level_low: int, level_high: int, edge_rise: int, edge_fall: int) -> None:
-        """Set |DigitalIn| trigger detector settings.
+        """Set |DigitalIn| trigger detector conditions.
+
+        The *level_low* and *level_high* settings effectively mask trigger detection events to clock cycles where
+        the selected pins are low or high, respectively.
+
+        The *edge_rise* and *edge_fall* indicate channels where the specific type of transition on any of the
+        included channels will lead to a trigger event, ar least if the level conditions specified by the *level_low*
+        and *level_high* settings are satisfied.
 
         Parameters:
-            level_low (int): Bit-field; channels that trigger when level is low.
-            level_high (int): Bit-field; channels that trigger when level is high.
-            edge_rise (int): Bit-field; channels that trigger at a rising edge.
-            edge_fall (int): Bit-field; channels that trigger at a falling edge.
+            level_low (int): The channels that are required to be low for a trigger event to occur (bitfield).
+            level_high (int): The channels that are required to be high for a trigger event to occur (bitfield).
+            edge_rise (int): The channels where a rising edge will cause a trigger event (bitfield).
+            edge_fall (int): The channels where a falling edge will cause a trigger event (bitfield).
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -904,10 +945,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerGet(self) -> Tuple[int, int, int, int]:
-        """Get |DigitalIn| trigger detector settings.
+        """Get the configured |DigitalIn| trigger detector settings.
 
         Returns:
-            Tuple[int, int, int, int]: bitfields for level_low, level_high, edge_rise, edge_fall sensitivity.
+            Tuple[int, int, int, int]: The currently active *level_low*, *level_high*, *edge_rise*,
+            and *edge_fall* settings.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -931,13 +973,13 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return (level_low, level_high, edge_rise, edge_fall)
 
     def triggerResetSet(self, level_low: int, level_high: int, edge_rise: int, edge_fall: int) -> None:
-        """Configure |DigitalIn| trigger detector reset settings.
+        """Configure |DigitalIn| trigger detector reset condition.
 
         Parameters:
-            level_low (int):  (to be documented)
-            level_high (int):  (to be documented)
-            edge_rise (int):  (to be documented)
-            edge_fall (int):  (to be documented)
+            level_low (int): The channels that are required to be low for a reset to occur (bitfield).
+            level_high (int): The channels that are required to be high for a reset to occur (bitfield).
+            edge_rise (int): The channels where a rising edge will cause a reset (bitfield).
+            edge_fall (int): The channels where a falling edge will cause a reset (bitfield).
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -952,10 +994,13 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerCountSet(self, count: int, restart: int) -> None:
-        """Set |DigitalIn| trigger detector count.
+        """Set the |DigitalIn| trigger detector count.
+
+        Todo:
+            Figure out what this setting does.
 
         Parameters:
-            count (int): (to be documented)
+            count (int): The event count.
             restart (int): (to be documented)
 
         Raises:
@@ -965,29 +1010,48 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerLengthSet(self, trigger_length_min: float, trigger_length_max: float, index_sync: int) -> None:
-        """Set |DigitalIn| trigger detector length.
+    def triggerLengthSet(self, min_length: float, max_length: float, sync_mode: int) -> None:
+        """Set the |DigitalIn| trigger detector length.
+
+        Todo:
+            Figure out what this setting does.
 
         Parameters:
-            trigger_length_min (int): (to be documented)
-            trigger_length_max (int): (to be documented)
-            index_sync (int): (to be documented)
+            min_length (float): (to be documented)
+            max_length (float): (to be documented)
+            sync_mode (int): Synchronization mode:
+
+                * 0 — Normal.
+                * 1 — Timing: the *min_length* parameter specifies the bit length and the *max_length* parameter
+                  specifies the timing length.
+
+                  Used for UART, CAN protocols.
+                * 2 — PWM: the *min_length* parameter specifies sthe ampling time and the *max_length* parameter
+                  specifies the timing length.
+
+                  Used for 1-wire protocols.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        result = self.lib.FDwfDigitalInTriggerLengthSet(self.hdwf, trigger_length_min, trigger_length_max, index_sync)
+        result = self.lib.FDwfDigitalInTriggerLengthSet(self.hdwf, min_length, max_length, sync_mode)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def triggerMatchSet(self, pin: int, mask: int, value: int, bit_stuffing: int) -> None:
         """Set |DigitalIn| trigger detector match.
 
+        Todo:
+            Figure out what this setting does.
+
+        Configure the deserializer. The bits are left shifted. the mask and value should be specified according to this,
+        in MSB-first order.
+
         Parameters:
-            pin (int): (to be documented)
-            mask (int): (to be documented)
-            value (int): (to be documented)
-            bit_stuffing (int): (to be documented)
+            pin (int): The pin to be deserialized.
+            mask (int): The mask pattern.
+            value (int): The bit pattern.
+            bit_stuffing (int): The bit stuffing count.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
