@@ -7,7 +7,7 @@ from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 
 
 class DigitalIO(AbstractDwfDeviceSubApi):
-    """The |DigitalIO| class provides access to the digital I/O functionality of a |DwfDevice:link|.
+    """The |DigitalIO| class provides access to the static digital I/O functionality of a |DwfDevice:link|.
 
     Attention:
         Users of |pydwf| should not create instances of this class directly.
