@@ -43,11 +43,11 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def clockSet(self, channel_index: int) -> None:
-        """Set the SPI clock channel.
+        """Set the digital channel (pin) for the SPI clock signal.
 
         Parameters:
             channel_index (int):
-                Digital channel (pin) for the clock signal.
+                The digital channel (pin) where the SPI clock signal will be generated.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -57,20 +57,20 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def dataSet(self, spi_data_bit: int, channel_index: int) -> None:
-        """Bind SPI data bit to a physical channel pin.
+        """Set the digital channel (pin) for an SPI data bit.
 
         Parameters:
             spi_data_bit (int):
 
                 The data bit to configure:
 
-                * 0 — DQ0 / MOSI
+                * 0 — DQ0 / MOSI / SISO
                 * 1 — DQ1 / MISO
                 * 2 — DQ2
                 * 3 — DQ3
 
             channel_index (int):
-                Digital channel (pin) for this data bit.
+                The digital channel (pin) for this data bit.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -80,20 +80,20 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def idleSet(self, spi_data_bit: int, idle_mode: DwfDigitalOutIdle) -> None:
-        """Set SPI data bit idle behavior.
+        """Set the idle behavior for an SPI data bit.
 
         Parameters:
             spi_data_bit (int):
 
                 The data bit to configure:
 
-                * 0 — DQ0 / MOSI
+                * 0 — DQ0 / MOSI / SISO
                 * 1 — DQ1 / MISO
                 * 2 — DQ2
                 * 3 — DQ3
 
             idle_mode (DwfDigitalOutIdle):
-                Idle behavior of this bit.
+                The idle behavior of this bit.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -109,7 +109,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
         Parameters:
             spi_mode (int):
 
-                The values for CPOL (polarity) and CPHA (phase) to use with the device under test:
+                The values for CPOL (polarity) and CPHA (phase) to use with the attached slave device:
 
                 * 0 — CPOL = 0, CPHA = 0
                 * 1 — CPOL = 0, CPHA = 1
@@ -149,7 +149,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
         Parameters:
 
             channel_index (int):
-                Digital channel (pin) for this data bit.
+                The digital channel (pin) for the Chip Select signal.
 
             level (int):
 
@@ -160,11 +160,11 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * -1 — Z (high impedance)
 
                 The CS (chip select) is usually an active-low signal, from the
-                SPI bus master to a specific SPI device. before starting a bus
+                SPI bus master to a specific SPI slave device. Before starting a bus
                 request, the master should set CS to 0 for the chip it wants to talk to.
 
-                Each slave on an SPI bus has its own CS line. Generally, either zero or
-                one of them should be low at any time.
+                Usually, each slave on an SPI bus has its own CS line. At most one of them
+                should be selected at any time.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
