@@ -442,17 +442,19 @@ class DwfAcquisitionMode(_FixReprMethod, enum.Enum):
     """Perform a single buffer acquisition.
 
     Re-arm the instrument for the next capture after the data is fetched to the host
-    using the *status()* method.
+    using the instrument-specific *Status()* method.
 
     Note:
-        The difference with the :py:attr:`Single` mode is unclear.
+        The difference with the :py:attr:`Single1` mode is unclear.
     """
 
     ScanShift = 1
     """Perform a continuous acquisition in FIFO style.
 
-    The trigger setting is ignored. The last sample is at the end of the buffer.
-    The *statusSamplesValid()* method shows the number of the acquired samples,
+    The trigger setting is ignored.
+
+    The last sample is at the end of the buffer.
+    The instrument's *statusSamplesValid()* method gives the number of the acquired samples,
     which will increase until reaching the buffer size.
     After that, the waveform image is shifted for every new sample.
     """
@@ -464,11 +466,11 @@ class DwfAcquisitionMode(_FixReprMethod, enum.Enum):
 
     The trigger setting is ignored.
 
-    The *statusIndexWrite()* value shows the buffer write position.
+    The instrument's *statusIndexWrite()* method gives the buffer write position.
     """
 
     Record = 3
-    """Perform acquisition for the length of time set by *recordLengthSet()* method."""
+    """Perform acquisition for the length of time set by the instrument's *recordLengthSet()* method."""
 
     Overs = 4
     """Overscan mode (undocumented)."""
@@ -560,7 +562,15 @@ class DwfAnalogOutFunction(_FixReprMethod, enum.Enum):
     """Enumeration type for analog output waveform-shape function constants.
 
     This type is used by the |AnalogOut| instrument to represent the wave-shape produced on an
-    analog output channel node.
+    analog output channel node. The nine fixed waveform shape options are shown below.
+
+    .. only:: html
+
+        .. image:: /images/waveforms.gif
+
+    .. only:: latex
+
+        .. image:: /images/waveforms.pdf
 
     In the C API, this type is called 'FUNC', and it is represented as an *unsigned char*.
     """
@@ -612,7 +622,7 @@ class DwfAnalogOutNode(_FixReprMethod, enum.Enum):
     """
 
     Carrier = 0
-    """Carrier signal node."""
+    """Carrier signal node. This node represents the base signal without modulation applied."""
 
     FM = 1
     """Frequency Modulation node."""
@@ -634,7 +644,7 @@ class DwfAnalogOutMode(_FixReprMethod, enum.Enum):
     """Voltage mode."""
 
     Current = 1
-    "Current mode."""
+    """Current mode."""
 
 
 @enum.unique
@@ -688,7 +698,11 @@ class DwfDigitalInSampleMode(_FixReprMethod, enum.Enum):
     """Only digital samples (no noise)."""
 
     Noise  = 1
-    """Alternate samples: (noise, sample, noise, sample, …) where noise is more than 1 transition between 2 samples."""
+    """Alternate samples (noise, sample, noise, sample, …) where noise is more than one transition between two samples.
+
+    This setting is available when the sample rate is less than the maximum clock frequency (i.e., the divider is
+    greater than one). Digital noise can indicate glitches or ringing.
+    """
 
 
 @enum.unique
