@@ -18,18 +18,16 @@ class AbstractDwfLibrarySubApi:
 
         Returns:
             DwfLibrary: The |DwfLibrary| instance.
-
-        :meta private:
         """
         return self._dwf
 
     @property
     def lib(self):
-        """Return the |ctypes:link| library.
-
-        Returns:
-            ctypes.CDLL: The |ctypes| library.
+        """Return the *ctypes* library.
 
         :meta private:
+
+        Returns:
+            ctypes.CDLL: The *ctypes* library.
         """
         return self.dwf.lib
